@@ -38,17 +38,17 @@ typedef struct _CamelDigestStoreClass CamelDigestStoreClass;
 
 struct _CamelDigestStore {
 	CamelStore parent;
-	
+
 };
 
 struct _CamelDigestStoreClass {
 	CamelStoreClass parent_class;
-	
+
 };
 
 CamelType camel_digest_store_get_type (void);
 
-CamelStore *camel_digest_store_new (const char *url);
+CamelStore *camel_digest_store_new (const gchar *url);
 
 G_END_DECLS
 
