@@ -125,7 +125,6 @@ static struct {
 	{ "junk-test",          (ESExpFunc *) junk_test,          0 },
 };
 
-
 static CamelMimeMessage *
 camel_filter_search_get_message (FilterMessageSearch *fms, struct _ESExp *sexp)
 {
@@ -206,7 +205,6 @@ header_contains (struct _ESExp *f, gint argc, struct _ESExpResult **argv, Filter
 	return check_header (f, argc, argv, fms, CAMEL_SEARCH_MATCH_CONTAINS);
 }
 
-
 static ESExpResult *
 header_matches (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
@@ -723,7 +721,7 @@ camel_filter_search_match (CamelSession *session,
 
 	sexp = e_sexp_new ();
 
-	for (i = 0; i < sizeof (symbols) / sizeof (symbols[0]); i++) {
+	for (i = 0; i < G_N_ELEMENTS (symbols); i++) {
 		if (symbols[i].type == 1)
 			e_sexp_add_ifunction (sexp, 0, symbols[i].name, (ESExpIFunc *)symbols[i].func, &fms);
 		else
