@@ -4,8 +4,8 @@
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -61,4 +61,4 @@ enum {
 
 G_END_DECLS
 
-#endif /* !_CAMEL_LOCK_HELPER_H */
+#endif /* _CAMEL_LOCK_HELPER_H */
