@@ -601,7 +601,7 @@ setup (void)
 	g_free (full_pfx);
 	g_free (cp_pfx);
 
-	localedir = replace_prefix (cp_prefix, EVOLUTION_LOCALEDIR);
+	localedir = replace_prefix (cp_prefix, E_DATA_SERVER_LOCALEDIR);
 	extensiondir = replace_prefix (prefix, E_DATA_SERVER_EXTENSIONDIR);
 	imagesdir = replace_prefix (prefix, E_DATA_SERVER_IMAGESDIR);
 	ui_uidir = replace_prefix (prefix, E_DATA_SERVER_UI_UIDIR);
